@@ -24,7 +24,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: psymodel.c,v 1.185 2008/06/26 08:57:34 bouvigne Exp $ */
+/* $Id: psymodel.c,v 1.185.2.2 2009/01/18 15:44:27 robert Exp $ */
 
 
 /*
@@ -507,8 +507,11 @@ vbrpsy_mask_add(FLOAT m1, FLOAT m2, int b)
     if (m2 < 0) {
         m2 = 0;
     }
-    if (m1 <= 0 && m2 <= 0) {
-        return 0;
+    if (m1 <= 0) {
+        return m2;
+    }
+    if (m2 <= 0) {
+        return m1;
     }
     if (m2 > m1) {
         ratio = m2 / m1;
@@ -762,7 +765,6 @@ compute_masking_s(lame_global_flags const *gfp,
                   FLOAT(*fftenergy_s)[HBLKSIZE_s], FLOAT * eb, FLOAT * thr, int chn, int sblock)
 {
     lame_internal_flags *const gfc = gfp->internal_flags;
-    FLOAT   max[CBANDS];
     int     i, j, b;
 
     for (b = j = 0; b < gfc->npart_s; ++b) {
@@ -775,7 +777,6 @@ compute_masking_s(lame_global_flags const *gfp,
                 m = el;
         }
         eb[b] = ebb;
-        max[b] = m;
     }
     assert(b == gfc->npart_s);
     assert(j == 129);
@@ -2825,7 +2826,7 @@ psymodel_init(lame_global_flags * gfp)
         for (k = 0; k < gfc->numlines_l[i]; k++, j++) {
             FLOAT const freq = sfreq * j / (1000.0 * BLKSIZE);
             FLOAT   level;
-            /* freq = Min(.1,freq); *//* ATH below 100 Hz constant, not further climbing */
+            /* freq = Min(.1,freq); */ /* ATH below 100 Hz constant, not further climbing */
             level = ATHformula(freq * 1000, gfp) - 20; /* scale to FFT units; returned value is in dB */
             level = pow(10., 0.1 * level); /* convert from dB -> energy */
             level *= gfc->numlines_l[i];
@@ -2877,7 +2878,7 @@ psymodel_init(lame_global_flags * gfp)
         for (k = 0; k < gfc->numlines_s[i]; k++, j++) {
             FLOAT const freq = sfreq * j / (1000.0 * BLKSIZE_s);
             FLOAT   level;
-            /* freq = Min(.1,freq); *//* ATH below 100 Hz constant, not further climbing */
+            /* freq = Min(.1,freq); */ /* ATH below 100 Hz constant, not further climbing */
             level = ATHformula(freq * 1000, gfp) - 20; /* scale to FFT units; returned value is in dB */
             level = pow(10., 0.1 * level); /* convert from dB -> energy */
             level *= gfc->numlines_s[i];
